@@ -3,7 +3,7 @@ import sys
 import copy
 import atexit
 import contextlib
-from .importlib_interface import Traversable, contents, is_resource, read_binary, read_text, files, as_file
+from .importlib_interface import EXE_PATH, Traversable, contents, is_resource, read_binary, read_text, files, as_file
 
 try:
     from dataclasses import MISSING
@@ -15,7 +15,7 @@ __all__ = [
     'ResourceNotAvailable', 'Resource', 'ResourceManagerInterface', 'ResourceManager',
     'get_global_manager', 'set_global_manager', 'temp_manager', 'add_manager', 'remove_manager',
     'clear', 'register', 'register_data', 'register_directory', 'unregister',
-    'has_resource', 'get_resources', 'get_resource', 'get_binary', 'get_text',
+    'has_resource', 'get_resources', 'get_resource', 'get_binary', 'get_text', 'registered_datas',
     'MISSING'
     ]
 
@@ -85,30 +85,37 @@ class Resource:
         try:
             return is_resource(self.package, self.name)
         except (AttributeError, TypeError, ValueError):
-            return False
+            try:
+                f = self.files()
+                return f.exists() and not f.is_dir()
+            except (AttributeError, TypeError, ValueError):
+                return False
 
     def files(self):
         try:
             return files(self.package).joinpath(self.name)
         except (AttributeError, TypeError, ValueError):
-            return self.package_path
+            return Traversable(self.package_path)
 
     @contextlib.contextmanager
     def as_file(self):
         f = self.files()
         try:
             with as_file(f) as file:
-                if not os.path.exists(str(file)):
-                    raise FileNotFoundError('The file does not exist!')
                 yield file
         except (ValueError, TypeError, FileNotFoundError, Exception) as err:
-            package_path = self.package_path
-            if os.path.exists(str(package_path)):
-                yield f
+            package_path = str(self.package_path)
+            if os.path.exists(package_path):
+                yield package_path
             else:
                 raise err
 
     def contents(self):
+        try:
+            if '/' in self.name or '\\' in self.name:
+                return [f.name for f in self.files().parent.iterdir()]
+        except (ValueError, TypeError, Exception):
+            pass
         try:
             return contents(self.package)
         except (ValueError, TypeError, Exception):
@@ -124,8 +131,13 @@ class Resource:
         try:
             self.data = read_binary(self.package, self.name)
             return self.data
-        except Exception as err:
+        except (AttributeError, TypeError, OSError, Exception) as err:
             error = err
+            try:
+                self.data = self.files().read_bytes()
+                return self.data
+            except (AttributeError, TypeError, OSError, Exception):
+                pass
         raise ResourceNotAvailable(str(error))
 
     read_binary = read_bytes
@@ -140,8 +152,13 @@ class Resource:
         try:
             self.data = read_text(self.package, self.name, encoding, errors)
             return self.data
-        except Exception as err:
+        except (AttributeError, TypeError, OSError, Exception) as err:
             error = err
+            try:
+                self.data = self.files().read_text(encoding, errors)
+                return self.data
+            except (AttributeError, TypeError, OSError, Exception):
+                pass
         raise ResourceNotAvailable(str(error))
 
     def _enter_context(self):
@@ -189,7 +206,9 @@ class Resource:
         # Return the simple package path from the working directory.
         pp = orig_pp = str(self.package_path)
         if not os.path.exists(pp):
-            pp = os.path.join(getattr(sys, '_MEIPASS', sys.executable), pp)
+            pp = os.path.join(EXE_PATH, pp)
+            if not os.path.exists(pp):
+                pp = os.path.join(EXE_PATH, '', pp)
             if not os.path.exists(pp):
                 pp = orig_pp
         return pp
@@ -200,7 +219,8 @@ class Resource:
 
     def __eq__(self, other):
         if isinstance(other, str):
-            return other == self.alias or other == self.package_path
+            return other == self.alias or \
+                   other.replace('\\', '/') == self.package_path
         return super().__eq__(other)
 
     def __repr__(self):
@@ -298,7 +318,7 @@ class ResourceManagerInterface(object):
         self.append(rsc)
         return rsc
 
-    def register_directory(self, package, extensions=None, exclude=None, **kwargs):
+    def register_directory(self, package, directory='', recursive=False, extensions=None, exclude=None, **kwargs):
         """Register all items in a directory.
 
         Note:
@@ -306,6 +326,8 @@ class ResourceManagerInterface(object):
 
         Args:
             package (str): Package name ('check_lib.check_sub')
+            directory (str)['']: Additional directory path.
+            recursive (bool)[False]: If True iterate through subdirectories and find all files.
             extensions (list/str)[None]: List of extensions to register (".csv", ".txt", "" for "LICENSE" with no ext).
                 If None register all.
             exclude (list/str)[None]: List of filenames to exclude.
@@ -321,14 +343,28 @@ class ResourceManagerInterface(object):
         elif isinstance(exclude, str):
             exclude = [exclude]
 
-        directory = []
-        for name in contents(package):
-            name = str(name)
-            ext = os.path.splitext(name)[-1]
-            if (name not in exclude) and (extensions is None or ext in extensions):
-                directory.append(self.register(package, name, **kwargs))
+        folder = []
+        pkg = files(package).joinpath(directory or '')
+        if directory or recursive:
+            if recursive:
+                iter_dir = pkg.glob('**/*')
+            else:
+                iter_dir = pkg.iterdir()
+            for f in iter_dir:
+                name = str(f.relative_to(pkg))
+                ext = os.path.splitext(name)[-1]
+                if not f.is_dir() and (name not in exclude) and (extensions is None or ext in extensions):
+                    path = os.path.join(directory, name).replace('\\', '/')  # Normalize path with the directory
+                    folder.append(self.register(package, path, **kwargs))
+        else:
+            for name in contents(package):
+                name = str(name)
+                ext = os.path.splitext(name)[-1]
+                f = pkg.joinpath(name)
+                if not f.is_dir() and (name not in exclude) and (extensions is None or ext in extensions):
+                    folder.append(self.register(package, name, **kwargs))
 
-        return directory
+        return folder
 
     def unregister(self, rsc=None, name=None, alias=None):
         """Unregister a resource.
@@ -552,7 +588,7 @@ def register_data(data, package, name, alias=MISSING, **kwargs):
     return get_global_manager().register_data(data, package, name, alias=alias, **kwargs)
 
 
-def register_directory(package, extensions=None, exclude=None, **kwargs):
+def register_directory(package, directory=None, recursive=False, extensions=None, exclude=None, **kwargs):
     """Register all items in a directory.
 
     Note:
@@ -560,6 +596,8 @@ def register_directory(package, extensions=None, exclude=None, **kwargs):
 
     Args:
         package (str): Package name ('check_lib.check_sub')
+        directory (str)[None]: Additional directory path.
+        recursive (bool)[False]: If True iterate through subdirectories and find all files.
         extensions (list/str)[None]: List of extensions to register (".csv", ".txt", "" for "LICENSE" with no ext).
             If None register all.
         exclude (list/str)[None]: List of filenames to exclude.
@@ -568,7 +606,8 @@ def register_directory(package, extensions=None, exclude=None, **kwargs):
     Returns:
         directory (list): List of Resource objects that were registered.
     """
-    return get_global_manager().register_directory(package, extensions=extensions, exclude=exclude, **kwargs)
+    return get_global_manager().register_directory(package, directory=directory, recursive=recursive,
+                                                   extensions=extensions, exclude=exclude, **kwargs)
 
 
 def unregister(rsc=None, name=None, alias=None):
@@ -643,3 +682,32 @@ def get_text(rsc, fallback=None, default=MISSING, encoding='utf-8', errors='stri
         text (str): Text data that was read.
     """
     return get_global_manager().get_text(rsc, fallback=fallback, default=default, encoding=encoding, errors=errors)
+
+
+def registered_datas(resource_manager=None, use_dest_dirs=True):
+    """Return a list of datas that were registered.
+
+    Args:
+        resource_manager (ResourceManager)[None]: Resource manger to use. If None use default global ResourceManager.
+        use_dest_dirs (bool)[True]: If True the destination will be a directory. If False the dest will be the filename.
+
+    Returns:
+        datas (list): List of (existing file path, rel install path).
+    """
+    if resource_manager is None:
+        resource_manager = get_global_manager()
+
+    datas = []
+
+    for man in [resource_manager] + resource_manager.managers:
+        for resource in man.get_resources():
+            if resource.is_resource():
+                with resource.as_file() as rsc_file:
+                    package_path = str(resource.package_path)
+                    if use_dest_dirs:
+                        package_path = os.path.dirname(package_path)
+                    data = (os.path.relpath(str(rsc_file)), package_path)
+                    if data not in datas:
+                        datas.append(data)
+
+    return datas
